BubbleContainer class
A rounded message bubble used by the Ensemble chat UI.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BubbleContainer
Constructors
- BubbleContainer({Key? key, required String text, double bubbleRadius = 25, Color color = Colors.white70, TextStyle textStyle = const TextStyle(color: Colors.white, fontSize: 17), required BubbleAlignment bubbleAlignment, EdgeInsets? padding, EdgeInsets? margin})
-
Creates a chat bubble.
const
Properties
- bubbleAlignment → BubbleAlignment
-
Controls whether the bubble is aligned left or right.
final
- bubbleRadius → double
-
Radius applied to the rounded bubble corners.
final
- color → Color
-
Background color for the bubble.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsets?
-
Optional outer spacing around the bubble.
final
- padding → EdgeInsets?
-
Optional inner spacing for the bubble content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Message text displayed inside the bubble.
final
- textStyle → TextStyle
-
Text style for text.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited