BubbleStyleComposite class
Style configuration for a chat bubble.
- Inheritance
-
- Object
- WidgetCompositeProperty
- BubbleStyleComposite
Constructors
- BubbleStyleComposite(ChangeNotifier widgetController)
-
Creates a bubble style composite attached to
widgetController. - BubbleStyleComposite.from(ChangeNotifier widgetController, dynamic payload)
-
Creates a style composite from an Ensemble payload.
factory
Properties
- backgroundColor ↔ Color?
-
Bubble background color.
getter/setter pair
- borderRadius ↔ double
-
Bubble corner radius.
getter/setter pair
- definition ↔ SourceSpan?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairinherited
- margin ↔ EdgeInsets
-
Outer spacing around each bubble.
getter/setter pair
- padding ↔ EdgeInsets
-
Inner spacing for bubble content.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor ↔ Color?
-
Bubble text color.
getter/setter pair
- textStyle ↔ TextStyle?
-
Optional full text style for bubble content.
getter/setter pair
- widgetController ↔ ChangeNotifier
-
getter/setter pairinherited
Methods
-
getList(
Object obj) → List? -
inherited
-
getMap(
Object obj) → Map? -
inherited
-
getMethod(
dynamic method) → Function? -
inherited
-
getProperty(
dynamic prop) → dynamic -
inherited
-
getString(
Object obj) → String? -
inherited
-
getters(
) → Map< String, Function> -
mark these functions as protected as we need the implementations,
but discourage direct usages.
Reasons:
override
-
hasGettableProperty(
dynamic prop) → bool -
inherited
-
hasMethod(
dynamic method) → bool -
inherited
-
hasSettableProperty(
dynamic prop) → bool -
inherited
-
methods(
) → Map< String, Function> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setProperty(
dynamic prop, dynamic val) → void -
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
-
setters(
) → Map< String, Function> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited